==> beast-privilege-api-2.6.4-GS-20230105.053150-12-sources.jar: com/thebeastshop/privilege/vo/GiftCampaignQualificationVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class GiftCampaignQualificationVO implements Serializable {
    private Integer id;
    private String name; //资格名称
    private Date qualificationStartDate; //资格可使用开始时间
    private Date qualificationEndDate; //资格可使用结束时间
    private Integer totalNum; //资格可使用次数
    private String orderChannelCode; //订单渠道
    private String orderType; //订单类型
    private String orderBusinessType; //订单业务类型
    private String memberLevel; //会员等级
    private Date orderStartDate; //下单开始时间
    private Date orderEndDate; //下单结束时间
    private Date payStartDate; //付款开始时间
    private Date payEndDate; //付款结束时间
    private Integer status; //状态 1：启用 0：禁用
    private String skuCode; //包含商品
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;



    private List<String> orderChannelCodeList;
    private List<Integer> orderTypeList;
    private List<Integer> orderBusinessTypeList;
    private List<Integer> memberLevelList;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getQualificationStartDate() {
        return qualificationStartDate;
    }

    public void setQualificationStartDate(Date qualificationStartDate) {
        this.qualificationStartDate = qualificationStartDate;
    }

    public Date getQualificationEndDate() {
        return qualificationEndDate;
    }

    public void setQualificationEndDate(Date qualificationEndDate) {
        this.qualificationEndDate = qualificationEndDate;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public String getOrderChannelCode() {
        return orderChannelCode;
    }

    public void setOrderChannelCode(String orderChannelCode) {
        this.orderChannelCode = orderChannelCode;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderBusinessType() {
        return orderBusinessType;
    }

    public void setOrderBusinessType(String orderBusinessType) {
        this.orderBusinessType = orderBusinessType;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getOrderStartDate() {
        return orderStartDate;
    }

    public void setOrderStartDate(Date orderStartDate) {
        this.orderStartDate = orderStartDate;
    }

    public Date getOrderEndDate() {
        return orderEndDate;
    }

    public void setOrderEndDate(Date orderEndDate) {
        this.orderEndDate = orderEndDate;
    }

    public Date getPayStartDate() {
        return payStartDate;
    }

    public void setPayStartDate(Date payStartDate) {
        this.payStartDate = payStartDate;
    }

    public Date getPayEndDate() {
        return payEndDate;
    }

    public void setPayEndDate(Date payEndDate) {
        this.payEndDate = payEndDate;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<String> getOrderChannelCodeList() {
        return orderChannelCodeList;
    }

    public void setOrderChannelCodeList(List<String> orderChannelCodeList) {
        this.orderChannelCodeList = orderChannelCodeList;
    }

    public List<Integer> getOrderTypeList() {
        return orderTypeList;
    }

    public void setOrderTypeList(List<Integer> orderTypeList) {
        this.orderTypeList = orderTypeList;
    }

    public List<Integer> getOrderBusinessTypeList() {
        return orderBusinessTypeList;
    }

    public void setOrderBusinessTypeList(List<Integer> orderBusinessTypeList) {
        this.orderBusinessTypeList = orderBusinessTypeList;
    }

    public List<Integer> getMemberLevelList() {
        return memberLevelList;
    }

    public void setMemberLevelList(List<Integer> memberLevelList) {
        this.memberLevelList = memberLevelList;
    }

}

==> beast-privilege-api-3.0.11-GS-20250828.090605-4-sources.jar: com/thebeastshop/privilege/vo/GiftCampaignQualificationVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class GiftCampaignQualificationVO implements Serializable {
    private Integer id;
    private String name; //资格名称
    private Date qualificationStartDate; //资格可使用开始时间
    private Date qualificationEndDate; //资格可使用结束时间
    private Integer totalNum; //资格可使用次数
    private String orderChannelCode; //订单渠道，逗号分隔
    private String orderType; //订单类型，逗号分隔
    private String orderBusinessType; //订单业务类型，逗号分隔
    private String memberLevel; //会员等级，逗号分隔
    private Date orderStartDate; //下单开始时间
    private Date orderEndDate; //下单结束时间
    private Date payStartDate; //付款开始时间
    private Date payEndDate; //付款结束时间
    private Integer status; //状态 1：启用 0：禁用
    private String skuCode; //包含商品
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;



    private List<String> orderChannelCodeList;
    private List<Integer> orderTypeList;
    private List<Integer> orderBusinessTypeList;
    private List<Integer> memberLevelList;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getQualificationStartDate() {
        return qualificationStartDate;
    }

    public void setQualificationStartDate(Date qualificationStartDate) {
        this.qualificationStartDate = qualificationStartDate;
    }

    public Date getQualificationEndDate() {
        return qualificationEndDate;
    }

    public void setQualificationEndDate(Date qualificationEndDate) {
        this.qualificationEndDate = qualificationEndDate;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public String getOrderChannelCode() {
        return orderChannelCode;
    }

    public void setOrderChannelCode(String orderChannelCode) {
        this.orderChannelCode = orderChannelCode;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderBusinessType() {
        return orderBusinessType;
    }

    public void setOrderBusinessType(String orderBusinessType) {
        this.orderBusinessType = orderBusinessType;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getOrderStartDate() {
        return orderStartDate;
    }

    public void setOrderStartDate(Date orderStartDate) {
        this.orderStartDate = orderStartDate;
    }

    public Date getOrderEndDate() {
        return orderEndDate;
    }

    public void setOrderEndDate(Date orderEndDate) {
        this.orderEndDate = orderEndDate;
    }

    public Date getPayStartDate() {
        return payStartDate;
    }

    public void setPayStartDate(Date payStartDate) {
        this.payStartDate = payStartDate;
    }

    public Date getPayEndDate() {
        return payEndDate;
    }

    public void setPayEndDate(Date payEndDate) {
        this.payEndDate = payEndDate;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<String> getOrderChannelCodeList() {
        return orderChannelCodeList;
    }

    public void setOrderChannelCodeList(List<String> orderChannelCodeList) {
        this.orderChannelCodeList = orderChannelCodeList;
    }

    public List<Integer> getOrderTypeList() {
        return orderTypeList;
    }

    public void setOrderTypeList(List<Integer> orderTypeList) {
        this.orderTypeList = orderTypeList;
    }

    public List<Integer> getOrderBusinessTypeList() {
        return orderBusinessTypeList;
    }

    public void setOrderBusinessTypeList(List<Integer> orderBusinessTypeList) {
        this.orderBusinessTypeList = orderBusinessTypeList;
    }

    public List<Integer> getMemberLevelList() {
        return memberLevelList;
    }

    public void setMemberLevelList(List<Integer> memberLevelList) {
        this.memberLevelList = memberLevelList;
    }

}
